@@ -5,6 +5,7 @@ import select
 import struct
 import time
 import os
+import datetime
 
 try:
     import pyraknet
@@ -134,6 +135,48 @@ class MongoDBTransport(Transport):
     @property
     def address(self):
         pass
+    
+class DelayedMongoDBTransport(Transport):
+    def __init__(self):
+        import bson
+        self.connection = None
+        self.database = None
+        self.collection = None
+        self._is_connected = False
+        self.get_time = bson.code.Code('function(){return new Date()}')
+    def listen(self, host, db, collection, connection_handler=None):
+        import pymongo
+        self.connection = pymongo.Connection(host)
+        self.database = self.connection[db]
+        self.collection = self.database[collection]
+    def poll(self, packet_handler):
+        import pymongo
+        processed = False
+        timestamp = self.database.eval(self.get_time)
+        msg = self.collection.find_one({'arrival_date' : {'$lt' : timestamp}}, sort=[('timestamp', pymongo.ASCENDING)])
+        if msg:
+            packet_handler(msg['message'], None)
+            processed = True
+            self.collection.remove(msg['_id'])
+        return processed
+    def connect(self, host, db, collection):
+        import pymongo
+        self.connection = pymongo.Connection(host)
+        self.database = self.connection[db]
+        self.collection = self.database[collection]
+    def disconnect(self):
+        self.connection.disconnect()
+        self.connection = None
+        self.database = None
+        self.collection = None
+    def send(self, data, address=None, broadcast=False, delay=0):
+        import bson
+        timestamp = self.database.eval(self.get_time)
+        ready_date = timestamp + datetime.timedelta(seconds=delay)
+        self.collection.insert({'timestamp': timestamp, 'arrival_date' : ready_date, 'message': bson.Binary(data=data)})
+    @property
+    def address(self):
+        pass
 
 class SelectTCPTransport(Transport):
     def __init__(self):
